@@ -15,6 +15,7 @@ from prometheus_client import start_http_server
 from prometheus_client.core import GaugeMetricFamily, REGISTRY
 
 from . import cluster_health_parser
+from . import indices_aliases_parser
 from . import indices_mappings_parser
 from . import indices_stats_parser
 from . import nodes_stats_parser
@@ -95,6 +96,33 @@ class NodesStatsCollector(object):
             yield collector_up_gauge(self.metric_name_list, self.description)
 
 
+class IndicesAliasesCollector(object):
+    def __init__(self, es_client, timeout):
+        self.metric_name_list = ['es', 'indices_aliases']
+        self.description = 'Indices Aliases'
+
+        self.es_client = es_client
+        self.timeout = timeout
+
+    def collect(self):
+        try:
+            response = self.es_client.indices.get_alias(request_timeout=self.timeout)
+
+            metrics = indices_aliases_parser.parse_response(response, self.metric_name_list)
+            metric_dict = group_metrics(metrics)
+        except ConnectionTimeout:
+            log.warning('Timeout while fetching %(description)s (timeout %(timeout_s)ss).',
+                        {'description': self.description, 'timeout_s': self.timeout})
+            yield collector_up_gauge(self.metric_name_list, self.description, succeeded=False)
+        except Exception:
+            log.exception('Error while fetching %(description)s.',
+                          {'description': self.description})
+            yield collector_up_gauge(self.metric_name_list, self.description, succeeded=False)
+        else:
+            yield from gauge_generator(metric_dict)
+            yield collector_up_gauge(self.metric_name_list, self.description)
+
+
 class IndicesMappingsCollector(object):
     def __init__(self, es_client, timeout):
         self.metric_name_list = ['es', 'indices_mappings']
@@ -370,9 +398,9 @@ CONFIGPARSER_CONVERTERS = {
               help='Port to serve the metrics endpoint on. (default: 9206)')
 @click.option('--query-disable', default=False, is_flag=True,
               help='Disable query monitoring. '
-                   'Config file does not need to be present if query monitoring is disabled.')
-@click.option('--config-file', '-c', default='exporter.cfg', type=click.File(),
-              help='Path to query config file. '
+                   'No config files/queries need to be present if query monitoring is disabled.')
+@click.option('--config-file', '-c', default='exporter.cfg', type=click.Path(dir_okay=False),
+              help='Path to the main query config file. '
                    'Can be absolute, or relative to the current working directory. '
                    '(default: exporter.cfg)')
 @click.option('--config-dir', default='./config', type=click.Path(file_okay=False),
@@ -398,6 +426,10 @@ CONFIGPARSER_CONVERTERS = {
               type=MultiChoice(NODES_STATS_METRICS_OPTIONS),
               help='Limit nodes stats to specific metrics. '
                    'Metrics should be separated by commas e.g. indices,fs.')
+@click.option('--indices-aliases-disable', default=False, is_flag=True,
+              help='Disable indices aliases monitoring.')
+@click.option('--indices-aliases-timeout', default=10.0,
+              help='Request timeout for indices aliases monitoring, in seconds. (default: 10)')
 @click.option('--indices-mappings-disable', default=False, is_flag=True,
               help='Disable indices mappings monitoring.')
 @click.option('--indices-mappings-timeout', default=10.0,
@@ -477,7 +509,7 @@ def cli(**options):
 
     if not options['query_disable']:
         config = configparser.ConfigParser(converters=CONFIGPARSER_CONVERTERS)
-        config.read_file(options['config_file'])
+        config.read(options['config_file'])
 
         config_dir_file_pattern = os.path.join(options['config_dir'], '*.cfg')
         config_dir_sorted_files = sorted(glob.glob(config_dir_file_pattern))
@@ -512,7 +544,8 @@ def cli(**options):
                              run_query, es_client, query_name, indices, query,
                              timeout, on_error, on_missing)
         else:
-            log.warning('No queries found in config file(s)')
+            log.error('No queries found in config file(s)')
+            return
 
     if not options['cluster_health_disable']:
         REGISTRY.register(ClusterHealthCollector(es_client,
@@ -524,6 +557,10 @@ def cli(**options):
                                               options['nodes_stats_timeout'],
                                               metrics=options['nodes_stats_metrics']))
 
+    if not options['indices_aliases_disable']:
+        REGISTRY.register(IndicesAliasesCollector(es_client,
+                                                  options['indices_aliases_timeout']))
+
     if not options['indices_mappings_disable']:
         REGISTRY.register(IndicesMappingsCollector(es_client,
                                                    options['indices_mappings_timeout']))
